#!/bin/bash
# install-ps2toolchain.sh by jimmikaelkael <jimmikaelkael@wanadoo.fr>
# Updated to use misfire's ps2dev mirror at github by SoulSlayer

source ./setup.sh

./${DISTRIB}/install-packages-ps2toolchain.sh

echo "Downloading ps2toolchain..."
cd ~/ || { echo "ERROR: failed to enter home user dir"; exit 1; }
rm -R ps2toolchain/
git clone git://github.com/ps2dev/ps2toolchain.git || { echo "ERROR: failed to retrieve ps2toolchain"; exit 1; }

echo "Building ps2toolchain..."
cd ps2toolchain/ || { echo "ERROR: failed to enter ps2toolchain dir"; exit 1; }
CC=gcc-${GCC_VERSION} ./toolchain-sudo.sh || { echo "ERROR: failed to run toolchain-sudo script"; exit 1; }

echo "Updating login script..."
HAVE_PS2DEV_ENV=`eval cat ~/.profile | sed -n 's/^.*PS2DEV=//p'`
if [ $HAVE_PS2DEV_ENV ]; then
echo "Already have PS2DEV env var" > /dev/null
else
echo "# PS2DEV/PS2SDK env vars" >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PS2DEV=/usr/local/ps2dev' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PATH=$PATH:$PS2DEV/bin' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PATH=$PATH:$PS2DEV/ee/bin' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PATH=$PATH:$PS2DEV/iop/bin' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PATH=$PATH:$PS2DEV/dvp/bin' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
fi
HAVE_PS2SDK_ENV=`eval cat ~/.profile | sed -n 's/^.*PS2SDK=//p'`
if [ $HAVE_PS2SDK_ENV ]; then
echo "Already have PS2SDK env var" > /dev/null
else
echo 'export PS2SDK=$PS2DEV/ps2sdk' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
echo 'export PATH=$PATH:$PS2SDK/bin' >> ~/.profile || { echo "ERROR: failed to update login script"; exit 1; }
fi

echo "Sourcing login script..."
source ~/.profile || { echo "ERROR: failed to source login script"; exit 1; }

echo "Building PS2SDK hello sample..."
cd $PS2SDK || { echo "ERROR: failed to enter PS2SDK dir"; exit 1; }
chmod -R a+w samples/ || { echo "ERROR: failed to change PS2SDK samples dir permissions"; exit 1; }
cd samples/hello/ || { echo "ERROR: failed to enter PS2SDK hello sample dir"; exit 1; }
make clean || { echo "ERROR: failed to clean PS2SDK hello sample"; exit 1; }
make || { echo "ERROR: failed to build PS2SDK hello sample"; exit 1; }

echo "Cleaning..."
rm -R ~/ps2toolchain/ || { echo "ERROR: failed to delete ps2toolchain dir"; exit 1; }

echo "PS2SDK installed successfully"

